import { ChatInputApplicationCommandData, CommandInteraction } from 'discord.js';
import BaseInteractionHandler, { BaseInteractionHandlerOptions } from '../../InteractionsAPI/BaseInteractionHandler';
import CommandInteractionManager from './CommandInteractionManager';
/**
 * @interface
 * @extends BaseInteractionHandlerOptions
 * @extends ChatInputApplicationCommandData
 */
export interface CommandInteractionHandlerOptions extends BaseInteractionHandlerOptions, ChatInputApplicationCommandData {
}
/**
 * The CommandInteraction handler
 * @class
 * @abstract
 */
export default abstract class CommandInteractionHandler extends BaseInteractionHandler {
    commandOptions: CommandInteractionHandlerOptions;
    /**
     * Handler for a Command Interaction. Will auto register with the manager supplied.
     * @constructor
     * @method
     * @param {CommandInteractionHandlerOptions} commandOptions The command options to supply
     * @param {CommandInteractionManager} manager The CommandInteractionManager
     * @public
     */
    constructor(commandOptions: CommandInteractionHandlerOptions, manager?: CommandInteractionManager);
    /**
     * Runs the interaction supplied
     * @method
     * @param {CommandInteraction} interaction The interaction to run
     * @public
     * @abstract
     */
    abstract run(interaction: CommandInteraction): Promise<unknown>;
}
