import { Client, CommandInteraction, Snowflake } from 'discord.js';
import BaseInteractionManager from '../../InteractionsAPI/BaseInteractionManager';
import CommandInteractionHandler from './CommandInteractionHandler';
/**
 * The CommandInteraction manager
 * @extends BaseInteractionManager
 * @class
 */
export default class CommandInteractionManager extends BaseInteractionManager<CommandInteraction, CommandInteractionHandler> {
    private client;
    /**
     * @constructor
     * @public
     * @param {Client} client The Discord.js Client
     */
    constructor(client: Client);
    /**
     * Gets the Interactions Id
     * @param {CommandInteraction} interaction The interaction's Id to return
     * @protected
     * @method
     * @returns
     */
    protected getInteractionId(interaction: CommandInteraction): Snowflake;
    /**
     * Calls the given interaction
     * @param {CommandInteraction} interaction The Interaction to call
     * @method
     * @protected
     */
    protected callInteraction(interaction: CommandInteraction): void;
    /**
     * Refreshes Guild or Global Commands
     * @param {Snowflake|String} guildId The guild Id to refresh Commands on
     * @public
     * @method
     * @returns
     */
    refreshCommands(guildId?: Snowflake): Promise<void>;
}
