"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const discord_js_1 = require("discord.js");
const BaseInteractionManager_1 = require("../../InteractionsAPI/BaseInteractionManager");
/**
 * The CommandInteraction manager
 * @extends BaseInteractionManager
 * @class
 */
class CommandInteractionManager extends BaseInteractionManager_1.default {
    /**
     * @constructor
     * @public
     * @param {Client} client The Discord.js Client
     */
    constructor(client) {
        super(discord_js_1.CommandInteraction);
        this.client = client;
        if (!(client instanceof discord_js_1.Client))
            throw new TypeError(`The client must be an instance of a discord.js Client`);
        this.client = client;
    }
    /**
     * Gets the Interactions Id
     * @param {CommandInteraction} interaction The interaction's Id to return
     * @protected
     * @method
     * @returns
     */
    getInteractionId(interaction) {
        if (!(interaction instanceof discord_js_1.CommandInteraction))
            throw new TypeError(`Interaction must be an instance of a CommandInteraction`);
        return interaction.commandName;
    }
    /**
     * Calls the given interaction
     * @param {CommandInteraction} interaction The Interaction to call
     * @method
     * @protected
     */
    callInteraction(interaction) {
        var _a;
        if (!(interaction instanceof discord_js_1.CommandInteraction))
            throw new TypeError(`Interaction must be an instance of a CommandInteraction`);
        (_a = this.getInteractionHandler(interaction)) === null || _a === void 0 ? void 0 : _a.run(interaction);
    }
    /**
     * Refreshes Guild or Global Commands
     * @param {Snowflake|String} guildId The guild Id to refresh Commands on
     * @public
     * @method
     * @returns
     */
    refreshCommands(guildId) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (guildId && typeof guildId !== 'string')
                throw new TypeError(`The guildId must be typeof 'string' `);
            const data = [];
            this.interactionHandlers.forEach((handler) => {
                data.push(handler.commandOptions);
            });
            if (guildId) {
                const guild = yield this.client.guilds.fetch(guildId);
                if (!guild)
                    return;
                yield guild.commands.set(data).catch((err) => {
                    throw new Error(err);
                });
            }
            else {
                yield ((_a = this.client.application) === null || _a === void 0 ? void 0 : _a.commands.set(data).catch((err) => {
                    throw new Error(err);
                }));
            }
        });
    }
}
exports.default = CommandInteractionManager;
