"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const discord_js_1 = require("discord.js");
/**
 * The base interaction manager
 * @class
 */
class BaseInteractionManager {
    /**
     * @constructor
     * @param {InteractionCtor} _interactionCtor
     * @public
     */
    constructor(_interactionCtor) {
        this._interactionCtor = _interactionCtor;
        this.interactionHandlers = new discord_js_1.Collection();
        this._interactionCtor = _interactionCtor;
    }
    /**
     * Registers a new Interaction Handler inside of a Collection
     * @param {ID_TYPE} Id The Id to set as the key
     * @param {H} handler The handler to set as the value
     * @method
     * @public
     */
    registerInteractionHandler(Id, handler) {
        this.interactionHandlers.set(Id, handler);
    }
    /**
     * Removes a Handler from the Interactions Handler Collection
     * @param {ID_TYPE} Id The Id to delete
     * @method
     * @public
     * @returns
     */
    removeInteractionHandler(Id) {
        return this.interactionHandlers.delete(Id);
    }
    /**
     * Fetches an Interaction handler
     * @param {I} interaction The interaction to get
     * @method
     * @protected
     * @returns
     */
    getInteractionHandler(interaction) {
        return this.interactionHandlers.get(this.getInteractionId(interaction));
    }
    /**
     * Call an interaction based on an event
     * @param {I} interaction The interaction to listen for
     * @method
     * @public
     */
    onInteraction(interaction) {
        this.callInteraction(interaction);
    }
}
exports.default = BaseInteractionManager;
