"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const discord_js_1 = require("discord.js");
/**
 * The Interaction Event handler, handles Interaction events
 */
class InteractionEventHandler {
    /**
     * @constructor
     * @public
     */
    constructor() {
        this.managers = new discord_js_1.Collection();
    }
    /**
     * Handles the interaction event
     * @param client The Discord.js Client
     * @public
     */
    hook(client) {
        client.on('interactionCreate', (i) => this._handleInteraction(i));
    }
    use(handlers) {
        const managers = Array.isArray(handlers)
            ? handlers
            : [handlers];
        for (const manager of managers) {
            this.managers.set(manager._interactionCtor, manager);
        }
    }
    /**
     * Internal function to handle interactions
     * @param interaction The interaction to handle|
     * @private
     */
    _handleInteraction(interaction) {
        this.managers.forEach((v, k) => {
            // note to self: we can also use ctor.isPrototypeOf to check for inherited inheritance (but not selfreference)
            if (Object.getPrototypeOf(interaction).constructor === k) {
                v.onInteraction(interaction);
            }
        });
    }
}
exports.default = InteractionEventHandler;
